<template>
    <div class="search-panel">
        <el-form ref="form" :model="form" label-width="90px" class="search-form">
            <el-form-item label="企业名称：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.eventName" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in form.eventNameList"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item label="资源环境：" size="mini" class="search-panel-item">
                <el-select style="width: 100%" v-model="form.pipelineType" @change="handlePipelineType"
                           :popper-class="'select-down'">
                    <el-option
                            v-for="item in items"
                            :key="item.code"
                            :label="item.name"
                            :value="item.name">
                    </el-option>
                </el-select>
            </el-form-item>
            <el-form-item :label="form.pipelineType+'：'" size="mini">
                <el-select style="width: 100%" v-model="form.dataType" value-key="code"
                           :popper-class="'select-down'" @change="handleDataType">
                    <el-option
                            v-for="item in subItems"
                            :key="item.code"
                            :label="item.name"
                            :value="item">
                    </el-option>
                </el-select>
            </el-form-item>
            <div class="rightButtonSearch">
                <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
                <el-button class="el-icon-search" @click="handleSearch"></el-button>
            </div>
        </el-form>
        <el-scrollbar style="height:286.22px">
            <div class="environmental-risk-list" v-for="(item,index) in list" :key="index"
                 :class="activeNum===index?'hover':''" @click="handleLocation(item,index)">
                <img class="state" :src="getImgSrc(item.properties.type)" style="background: none"/>
                <h3>{{changeAmount}}类型:{{item.properties.type}}</h3>
                <h5>{{changeAmount}}名称:{{item.properties.name}}</h5>
                <p>负责人:<span>{{item.properties.resperson}}</span></p>
                <p>电话:<span>{{item.properties.telephone}}</span></p>
            </div>
        </el-scrollbar>
    </div>
</template>

<script>
import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'
// import { LayerEmergency } from '../../../../../conf/LayerEmergency'
import { LayerEmergencySource } from '../../../../conf/layers/LayerEmergencySource'
import { LayerSurroundings } from '../../../../conf/layers/LayerSurroundings'
import { pulseEffect } from '../../../../utils/utils'
import { openPopup } from '../../../helpers/LocateHelper'
// import { fitBounds, highlight, openPopup } from '../../helpers/LocateHelper'

export default {
  name: 'ResourcesQuery',
  data () {
    return {
      form: {
        eventName: '',
        pipelineType: LayerEmergencySource.name,
        dataType: '',
        keyword: '',
        eventNameList: [
          { name: '金陵石化' },
          { name: '南京化学' }
        ]
      },
      activeNum: -1,
      list: [],
      items: [LayerEmergencySource, LayerSurroundings],
      subItems: LayerEmergencySource.layers || LayerSurroundings.layers,
      WfsHelper: null,
      changeAmount: '资源'
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  },
  methods: {
    getImgSrc (type) {
      // console.log(type)
      // const icon = this.form.dataType.icon
      return 'assets/images/map/sewers/' + type + '.png'
    },
    handlePipelineType (val) {
      // console.log(val)
      this.list = []
      for (let i = 0; i < this.items.length; i++) {
        const item = this.items[i].name
        if (val === item.name) {
          this.subItems = item.layers
          return
        }
      }
      if (this.form.pipelineType === '应急资源') {
        this.subItems = LayerEmergencySource.layers
        this.changeAmount = '资源'
      } else if (this.form.pipelineType === '周边环境') {
        this.subItems = LayerSurroundings.layers
        this.changeAmount = '环境'
      }
    },
    handleDataType (val) {
      // console.log(val)
      this.list = []
    },
    async handleSearch () {
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在企业应急还没区分开类型，后面改
      // console.log(this.form.dataType)
      // this.wfsHelper.setTypeName([this.form.dataType.typeName])
      this.wfsHelper.setTypeName(['sewer:emergency'])
      this.wfsHelper.setMaxFeatures(100)
      if (this.form.dataType) {
        this.wfsHelper.addEquals('type', '\'' + this.form.dataType.name + '\'')
      }
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      // console.log(res)
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.list = res.features
      }
    },
    // 查询定位功能
    handleLocation (val, index) {
      // console.log(val)
      this.activeNum = index
      const positionArea = [val.properties.y, val.properties.x]
      window.map.setView(positionArea, 16)
      pulseEffect(positionArea)
      openPopup(positionArea, val.id)
    }
  }
}
</script>

<style lang="less" scoped>

</style>
